==> haskell-test-framework-leancheck-0.0.1-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-leancheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-framework-leancheck
version:              0.0.1
visibility:           public
id:                   test-framework-leancheck-0.0.1-9JOJira6Xty2KGUBETpyGY
key:                  test-framework-leancheck-0.0.1-9JOJira6Xty2KGUBETpyGY
license:              BSD-3-Clause
maintainer:           Rudy Matela <rudy@matela.com.br>
author:               Rudy Matela <rudy@matela.com.br>
homepage:
    https://github.com/rudymatela/test-framework-leancheck#readme

synopsis:             LeanCheck support for test-framework.
description:
    LeanCheck support for test-framework.

    This package can be used to incorporate LeanCheck tests
    into test-framework test suites by means of the
    @Test.Framework.Providers.LeanCheck.testProperty@ function.

    Please see the Haddock documentation and README for more details.

category:             Testing
abi:                  c6598992192cd310c25993de66fe4be9
exposed:              True
exposed-modules:      Test.Framework.Providers.LeanCheck
import-dirs:
    /usr/lib/ghc-8.10.4/site-local/test-framework-leancheck-0.0.1

library-dirs:
    /usr/lib/ghc-8.10.4/site-local/test-framework-leancheck-0.0.1

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/test-framework-leancheck-0.0.1

hs-libraries:         HStest-framework-leancheck-0.0.1-9JOJira6Xty2KGUBETpyGY
depends:
    base-4.14.1.0 leancheck-0.9.3-1sKCvqTVi3M636RaP3sUTx
    test-framework-0.8.2.0-KEQDuK1qG1OlQL1WqL9cO

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-leancheck/html/test-framework-leancheck.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-leancheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-leancheck-0.0.1-65-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-leancheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-framework-leancheck
version:              0.0.1
visibility:           public
id:                   test-framework-leancheck-0.0.1-2pAeGJC3qYVGqBILNw5JgB
key:                  test-framework-leancheck-0.0.1-2pAeGJC3qYVGqBILNw5JgB
license:              BSD-3-Clause
maintainer:           Rudy Matela <rudy@matela.com.br>
author:               Rudy Matela <rudy@matela.com.br>
homepage:
    https://github.com/rudymatela/test-framework-leancheck#readme

synopsis:             LeanCheck support for test-framework.
description:
    LeanCheck support for test-framework.

    This package can be used to incorporate LeanCheck tests
    into test-framework test suites by means of the
    @Test.Framework.Providers.LeanCheck.testProperty@ function.

    Please see the Haddock documentation and README for more details.

category:             Testing
abi:                  37f0364f220adae9be2bb65ca146c78a
exposed:              True
exposed-modules:      Test.Framework.Providers.LeanCheck
import-dirs:
    /usr/lib/ghc-8.10.4/site-local/test-framework-leancheck-0.0.1

library-dirs:
    /usr/lib/ghc-8.10.4/site-local/test-framework-leancheck-0.0.1

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/test-framework-leancheck-0.0.1

hs-libraries:         HStest-framework-leancheck-0.0.1-2pAeGJC3qYVGqBILNw5JgB
depends:
    base-4.14.1.0 leancheck-0.9.3-1sKCvqTVi3M636RaP3sUTx
    test-framework-0.8.2.0-1hJhnVpzvyfL9PhiJUZ9yi

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-leancheck/html/test-framework-leancheck.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-leancheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
